Index: chrome/android/testshell/java/src/org/chromium/chrome/shell/ChromeShellApplicationObserver.java |
diff --git a/chrome/android/testshell/java/src/org/chromium/chrome/shell/ChromiumTestShellApplicationObserver.java b/chrome/android/testshell/java/src/org/chromium/chrome/shell/ChromeShellApplicationObserver.java |
similarity index 77% |
rename from chrome/android/testshell/java/src/org/chromium/chrome/shell/ChromiumTestShellApplicationObserver.java |
rename to chrome/android/testshell/java/src/org/chromium/chrome/shell/ChromeShellApplicationObserver.java |
index 0a5d382f4d558765b911a6fb615c8b3f6ba06db9..25aae36bd09cb2f2c1e283d8bf3691ac53c603a9 100644 |
--- a/chrome/android/testshell/java/src/org/chromium/chrome/shell/ChromiumTestShellApplicationObserver.java |
+++ b/chrome/android/testshell/java/src/org/chromium/chrome/shell/ChromeShellApplicationObserver.java |
@@ -7,9 +7,9 @@ package org.chromium.chrome.shell; |
import android.content.Intent; |
/** |
* Monitors events happening in {@link ChromiumTestShellApplication}. |
*/ |
-public interface ChromiumTestShellApplicationObserver { |
+public interface ChromeShellApplicationObserver { |
/** |
* Called when an Intent is about to be broadcast. |
* @return Whether or not the Application should really fire the broadcast. |
@@ -7,9 +7,9 @@ package org.chromium.chrome.shell; |
import android.content.Intent; |
/** |
- * Monitors events happening in {@link ChromiumTestShellApplication}. |
+ * Monitors events happening in {@link ChromeShellApplication}. |
*/ |